@@ -44,3 +44,8 @@ def btc():
 @pytest.fixture
 def zar():
     return 'ZAR'
+
+
+@pytest.fixture
+def subaccount_id():
+    return '909461317243875555'
